package com.company.cloud.sdk.weixin.common.model;

import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

public class BaseModel {


    /**
     * 将建构的 builder 转为 Map
     * @return 转化后的 Map
     */
    public Map<String, Object> toMap() {
        String[] fieldNames = getFiledNames(this);
        HashMap<String, Object> map = new HashMap<String, Object>(fieldNames.length);
        for (String name : fieldNames) {
            Object value = getFieldValueByName(name, this);
            if(value!=null){
                map.put(name, value);
            }
        }
        return map;
    }


    /**
     * 获取属性名数组
     */
    public String[] getFiledNames(Object obj) {
        Field[] fields = obj.getClass().getDeclaredFields();
        String[] fieldNames = new String[fields.length];
        for (int i = 0; i < fields.length; i++) {
            fieldNames[i] = fields[i].getName();
        }
        return fieldNames;
    }
    /**
     * 根据属性名获取属性值
     */
    public Object getFieldValueByName(String fieldName, Object obj) {
        try {
            String firstLetter = fieldName.substring(0, 1).toUpperCase();
            String getter = new StringBuffer().append("get")
                    .append(firstLetter)
                    .append(fieldName.substring(1))
                    .toString();
            Method method = obj.getClass().getMethod(getter);
            return method.invoke(obj);
        } catch (Exception e) {
            return null;
        }
    }



}
