package com.company.cloud.sdk.weixin.im;

import com.company.cloud.sdk.weixin.im.enums.WxIMApiType;
import com.company.cloud.sdk.weixin.im.model.IMBaseRespModel;
import com.company.cloud.sdk.weixin.im.model.account.*;
import com.company.cloud.sdk.weixin.im.utils.WxIMUtils;

/**
 * @Author dhz
 * @Date 2022/9/23 13:11
 */
public class WxImAccountAPi {

    /**
     * 导入单个帐号
     * 参考: https://cloud.tencent.com/document/product/269/1608
     */
    public static IMBaseRespModel accountImport(AccountImportModel entity) {
        String url = WxIMUtils.getUrl(WxIMApiType.account_import.getType(),entity);
        return WxIMUtils.postReq(new IMBaseRespModel(),url, entity);
    }


    /**
     * 导入多个帐号
     * 参考: https://cloud.tencent.com/document/product/269/4919
     */
    public static IMBaseRespModel accountBatchImport(AccountBatchImportModel entity) {
        String url = WxIMUtils.getUrl(WxIMApiType.multiaccount_import.getType(),entity);
        return WxIMUtils.postReq(new IMBaseRespModel(),url, entity);
    }


    /**
     * 删除帐号
     * 参考:https://cloud.tencent.com/document/product/269/36443
     */
    public static AccountDeleteRespModel deleteAccount(AccountDeleteItemsModel entity) {
        String url = WxIMUtils.getUrl(WxIMApiType.account_delete.getType(),entity);
        return WxIMUtils.postReq(new AccountDeleteRespModel(),url, entity);
    }


    /**
     * 查询帐号
     * 参考: https://cloud.tencent.com/document/product/269/38417
     */
    public static AccountCheckRespModel accountCheck(AccountCheckModel entity) {
        String url = WxIMUtils.getUrl(WxIMApiType.account_check.getType(),entity);
        return WxIMUtils.postReq(new AccountCheckRespModel(),url, entity);
    }



    /**
     * 失效帐号登录状态
     * 参考: https://cloud.tencent.com/document/product/269/3853
     */
    public static IMBaseRespModel accountKick(AccountKickModel entity) {
        String url = WxIMUtils.getUrl(WxIMApiType.kick.getType(),entity);
        return WxIMUtils.postReq(new IMBaseRespModel(),url, entity);
    }


    /**
     * 查询帐号在线状态
     * 参考: https://cloud.tencent.com/document/product/269/2566
     */
    public static AccountQueryOnlineRespModel accountQueryOnlineStatus(AccountQueryOnlineStatusModel entity) {
        String url = WxIMUtils.getUrl(WxIMApiType.query_online_status.getType(),entity);
        return WxIMUtils.postReq(new AccountQueryOnlineRespModel(),url, entity);
    }


}
