package com.company.cloud.sdk.weixin.im.utils;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.company.cloud.sdk.weixin.common.constant.WxErrorEnum;
import com.company.cloud.sdk.weixin.common.constant.WxHttpMethodEnum;
import com.company.cloud.sdk.weixin.common.exception.WxException;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.sdk.weixin.common.utils.UrlUtils;
import com.company.cloud.sdk.weixin.im.model.IMBaseRespModel;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

public class IMWxHttpRequestUtils {

    public static String getReqUrl(String wxApi, String wxDomain, Map<String, Object> baseParams) {
        String url = wxDomain.concat(wxApi);
        if (null == baseParams) {
            return url;
        }
        return UrlUtils.getParseUrl(url, baseParams);
    }

    public static String req(String wxApi, WxHttpMethodEnum method, String wxDomain, Map<String, Object> params) {
        try {
            Map<String, Object> baseParams = null;
            String accessToken = (String) params.get("access_token");
            if (null != accessToken) {
                baseParams = new HashMap<String, Object>();
                baseParams.put("access_token", accessToken);
                params.remove("access_token");
            }

            String suiteAccessToken = (String) params.get("suite_access_token");
            if (null != suiteAccessToken) {
                baseParams = new HashMap<String, Object>();
                baseParams.put("suite_access_token", accessToken);
                params.remove("suite_access_token");
            }

            String url = getReqUrl(wxApi, wxDomain, baseParams);
            if (WxHttpMethodEnum.FORM.equals(method)) {
                return HttpUtil.post(url, params);
            } else if (WxHttpMethodEnum.POST.equals(method)) {
                return HttpUtil.post(url, JSONObject.toJSONString(params));
            }
            return HttpUtil.get(url, params);
        } catch (Exception e) {
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(), e.getMessage());
        }
    }

    public static <T extends IMBaseRespModel> T getResp(T t, String wxApi, WxHttpMethodEnum method, String wxDomain, Object entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        String result = req(wxApi, method, wxDomain, params);
        if (StrUtil.isEmpty(result)) {
            throw new WxException(WxErrorEnum.WX_Http_ERROR);
        }
        Map<String, Object> resultMap = JSON.parseObject(result, Map.class);
        T data = BeanUtil.fillBeanWithMapIgnoreCase(resultMap, t, false);
        if (data.getActionStatus() != "OK" && data.getErrorCode() != 0) {
            throw new WxException(data.getErrorCode(), data.getErrorInfo());
        }
        return data;
    }

    // get请求
    public static <T extends IMBaseRespModel> T getReq(T t, String wxApi, String wxDomain, Object entity) {
        return getResp(t, wxApi, WxHttpMethodEnum.GET, wxDomain, entity);
    }

    // post请求
    public static <T extends IMBaseRespModel> T postReq(T t, String wxApi, String wxDomain, Object entity) {
        return getResp(t, wxApi, WxHttpMethodEnum.POST, wxDomain, entity);
    }

    // 表单请求
    public static <T extends IMBaseRespModel> T formReq(T t, String wxApi, String wxDomain, Object entity) {
        return getResp(t, wxApi, WxHttpMethodEnum.FORM, wxDomain, entity);
    }

    // 下载文件请求
    public static File fileReq(String wxApi, String wxDomain, Object entity) {
        HttpURLConnection conn = null;
        try {
            Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
            String url = getReqUrl(wxApi,  wxDomain, params);
            URL u = new URL(url);
            conn = (HttpURLConnection) u.openConnection();
            conn.setRequestMethod("POST");
            conn.connect();
            BufferedInputStream bis = new BufferedInputStream(conn.getInputStream());
            String content_disposition = conn.getHeaderField("content-disposition");
            //微信服务器生成的文件名称
            String file_name ="";
            String[] content_arr = content_disposition.split(";");
            if(content_arr.length  == 2){
                String tmp = content_arr[1];
                int index = tmp.indexOf("\"");
                file_name =tmp.substring(index+1, tmp.length()-1);
            }
            //生成不同文件名称
            File file = new File(file_name);
            BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(file));
            byte[] buf = new byte[2048];
            int length = bis.read(buf);
            while(length != -1){
                bos.write(buf, 0, length);
                length = bis.read(buf);
            }
            bos.close();
            bis.close();
            return file;
        } catch (IOException e) {
            e.printStackTrace();
        } catch (Exception e) {
            throw new WxException(e.getMessage());
        }finally {
            conn.disconnect();
        }
        return null;
    }
}
