package com.company.cloud.sdk.weixin.mini;

import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.sdk.weixin.mini.enums.WxMiniApiType;
import com.company.cloud.sdk.weixin.mini.model.message.MediaUploadModel;
import com.company.cloud.sdk.weixin.mini.model.message.MediaUploadResp;
import com.company.cloud.sdk.weixin.mini.model.message.SendToUserModel;
import com.company.cloud.sdk.weixin.mini.model.message.SetMsgTypingModel;
import com.company.cloud.sdk.weixin.mini.utils.WxMiniUtils;

/**
 * 小程序客服消息API
 * */
public class WxMessageCustomerApi {


    /**
     * 发送客服消息给用户
     * 参考：https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/customer-message/customerServiceMessage.send.html
     */
    public static BaseRespModel send(SendToUserModel entity) {
        return WxMiniUtils.postReq(new BaseRespModel(), WxMiniApiType.SendToUser.getType(), entity);
    }

    /**
     * 下发客服当前输入状态给用户
     * 参考：https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/customer-message/customerServiceMessage.setTyping.html
     */
    public static BaseRespModel setTyping(SetMsgTypingModel entity) {
        return WxMiniUtils.postReq(new BaseRespModel(), WxMiniApiType.SendTypingCommand.getType(), entity);
    }

    /**
     * 把媒体文件上传到微信服务器
     * 参考：https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/customer-message/customerServiceMessage.uploadTempMedia.html
     */
    public static MediaUploadResp uploadTempMedia(MediaUploadModel entity) {
        return WxMiniUtils.formReq(new MediaUploadResp(), WxMiniApiType.MediaUpload.getType(), entity);
    }
}
