package com.company.cloud.sdk.weixin.mini;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.company.cloud.sdk.weixin.common.constant.WxErrorEnum;
import com.company.cloud.sdk.weixin.common.exception.WxException;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.sdk.weixin.mini.enums.WxMiniApiType;
import com.company.cloud.sdk.weixin.mini.enums.WxMiniDomain;
import com.company.cloud.sdk.weixin.mini.model.Code2SessionModel;
import com.company.cloud.sdk.weixin.mini.model.Code2SessionResp;
import com.company.cloud.sdk.weixin.mini.model.DecryptDataModel;
import com.company.cloud.sdk.weixin.mini.model.WxMiniSendMsgModel;
import com.company.cloud.sdk.weixin.mini.utils.WxMiniUtils;
import com.sun.org.apache.xerces.internal.impl.dv.util.Base64;

import javax.crypto.Cipher;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.security.spec.AlgorithmParameterSpec;
import java.util.Map;

/**微信小程序API*/
public class WxMiniApi {


    /**
     * 登录凭证校验
     */
    public static Code2SessionResp code2Session(Code2SessionModel model) {
        return  WxMiniUtils.getReq(new Code2SessionResp(), WxMiniApiType.Code2Session.getType(), model);
    }

    /**
     * 小程序消息服务uniformMessage.send
     * https://api.weixin.qq.com/cgi-bin/message/wxopen/template/uniform_send?access_token=ACCESS_TOKEN
     */
    public static BaseRespModel uniformSend(WxMiniSendMsgModel model) {
        return WxMiniUtils.postReq(new BaseRespModel(), WxMiniApiType.SendMessage.getType(), model.toMap());
    }

    /**
     * 数据解密
     * */
    public static String decryptData(DecryptDataModel entity){
        if(entity==null){
            throw new WxException(WxErrorEnum.WX_Para_NULL);
        }
        if(StrUtil.hasEmpty(entity.getEncryptedData(),entity.getIv(),entity.getSessionKey())){
            throw new WxException(WxErrorEnum.WX_Para_NULL);
        }
        try {
            byte[] encrypData = Base64.decode(entity.getEncryptedData());
            byte[] ivData = Base64.decode(entity.getIv());
            byte[] sessionKeyByte = Base64.decode(entity.getSessionKey());
            AlgorithmParameterSpec ivSpec = new IvParameterSpec(ivData);
            Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
            SecretKeySpec keySpec = new SecretKeySpec(sessionKeyByte, "AES");
            cipher.init(Cipher.DECRYPT_MODE, keySpec, ivSpec);
            //解析解密后的字符串
            String decryptDataResult = new String(cipher.doFinal(encrypData),"UTF-8");
            System.out.println(StrUtil.format("++++解析解密后的字符串={}",decryptDataResult));
            JSONObject jsonObjects = JSONObject.parseObject(decryptDataResult);
            return jsonObjects.getString("phoneNumber");
        }catch (Exception e){
            System.out.println(e);
            throw new WxException(WxErrorEnum.WX_Decrypt_ERROR);
        }
    }


    public static void main(String[] args) {
        Code2SessionModel param=new Code2SessionModel();
        param.setAppid("wxc42ae6dc5e0882e1");
        param.setSecret("ba5593185158601be7cbe40e19b4221e");
        param.setJs_code("0f1NelFa1ZgesF0bqYGa1ZAqLS3NelFy");
        Code2SessionResp resp= WxMiniApi.code2Session(param);
        System.out.println(resp.getOpenid());
    }
}
