package com.company.cloud.sdk.weixin.mini.model.message;

import cn.hutool.core.util.StrUtil;
import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import com.company.cloud.sdk.weixin.common.utils.EnumValid;
import com.company.cloud.sdk.weixin.mini.enums.WxMiniEnum;
import lombok.Data;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.AssertTrue;
import javax.validation.constraints.NotEmpty;

@Getter
@Setter
public class SendToUserModel extends BaseReqModel {


    /**
     *用户的 OpenID
     */
    @NotEmpty(message = "用户的OpenID不能为空")
    private String touser;
    /**
     *消息类型
     */
    @NotEmpty(message = "消息类型不能为空")
    @EnumValid(target = WxMiniEnum.KfMsgType.class,message = "消息类型传值非法")
    private String msgtype;
    /**
     *文本消息（msgtype="text" 时必填）
     */
    private TextMessage text;

    @AssertTrue
    private Boolean isHaveText(){
        if(WxMiniEnum.KfMsgType.Kf_Text.getCode().equals(msgtype)){
            if(StrUtil.isBlank(text.getContent())){
                return false;
            }
        }
        return true;
    }
    /**
     *图片消息，msgtype="image" 时必填
     */
    private ImageMessage	imag;
    @AssertTrue
    private Boolean isHaveImag(){
        if(WxMiniEnum.KfMsgType.Kf_Image.getCode().equals(msgtype)){
            if(StrUtil.isBlank(imag.getMedia_id())){
                return false;
            }
        }
        return true;
    }
    /**
     *图文链接，msgtype="link" 时必填
     */
    private LinkMessage	link;
    @AssertTrue
    private Boolean isHaveLink(){
        if(WxMiniEnum.KfMsgType.Kf_Link.getCode().equals(msgtype)){
            if(StrUtil.isBlank(link.getTitle())
                    ||StrUtil.isBlank(link.getDescription())
                    ||StrUtil.isBlank(link.getThumb_url())
                    ||StrUtil.isBlank(link.getUrl())){
                return false;
            }
        }
        return true;
    }
    /**
     *小程序卡片，msgtype="miniprogrampage" 时必填
     */
    private MiniprogrampageMessage	miniprogrampage;
    @AssertTrue
    private Boolean isHaveMiniprogrampage(){
        if(WxMiniEnum.KfMsgType.Kf_Miniprogrampage.getCode().equals(msgtype)){
            if(StrUtil.isBlank(miniprogrampage.getTitle())
                    ||StrUtil.isBlank(miniprogrampage.getPagepath())
                    || StrUtil.isBlank(miniprogrampage.getThumb_media_id())){
                return false;
            }
        }
        return true;
    }

    @Data
    public static class TextMessage {
        private String content;
    }
    @Data
    private class ImageMessage {
        private String media_id;
    }
    @Data
    private class LinkMessage {
        private String title;
        private String description;
        private String url;
        private String thumb_url;
    }
    @Data
    private class MiniprogrampageMessage {
        private String title;
        private String pagepath;
        private String thumb_media_id;
    }


}
