package com.company.cloud.sdk.weixin.mp;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson.JSON;
import com.company.cloud.sdk.weixin.common.model.WxJSSDKSignModel;
import com.company.cloud.sdk.weixin.common.utils.WxJSSDKSignUtils;
import com.company.cloud.sdk.weixin.mp.enums.WxMpApiType;
import com.company.cloud.sdk.weixin.mp.enums.WxMpDomain;
import com.company.cloud.sdk.weixin.mp.model.*;
import com.company.cloud.sdk.weixin.mp.model.autoreply.CurrentAutoReplyInfoModel;
import com.company.cloud.sdk.weixin.mp.model.msgmanage.SendTempMsgModel;
import com.company.cloud.sdk.weixin.mp.model.msgmanage.SendTempMsgResp;
import com.company.cloud.sdk.weixin.mp.utils.WxMpUtils;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;

import java.util.HashMap;
import java.util.Map;

/**微信公众号API*/
public class WxMpApi {

    /**
     * 基础access_token:access_token (公众号和小程序均可以使用AppID和AppSecret调用本接口来获取access_token)
     * */
    public static AccessTokenResp accessToken(AccessTokenModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.getReq(new AccessTokenResp(), WxMpApiType.Access_Token, params);
    }

    /**
     * jsapi_ticket
     * https://developers.weixin.qq.com/doc/offiaccount/OA_Web_Apps/JS-SDK.html#62
     * */
    public static JsapiTicketResp jsapiTicket(JsapiTicketModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.getReq(new JsapiTicketResp(), WxMpApiType.Jsapi_Ticket, params);
    }

    /**
     *网页授权:用户同意授权，获取code
     * */
    public static Authorize2CodeResp authorize2Code(Authorize2CodeModel entity) {
        String url = WxMpUtils.getReqUrl(WxMpApiType.Authorize2Code, WxMpDomain.OPEN);
        String path = url.concat("?appid="+entity.getAppid()+"&redirect_uri="+entity.getRedirect_uri()+"&response_type=code&scope="+entity.getScope().getScope()+"&state="+entity.getState()+"#wechat_redirect");
        Authorize2CodeResp resp = new Authorize2CodeResp();
        resp.setUrl(path);
        return  resp;
    }

    /**
     *页面access_token:通过code换取网页授权access_token
     * */
    public static Code2AccessTokenResp code2Ticket(Code2AccessTokenModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.getReq(new Code2AccessTokenResp(), WxMpApiType.Code2AccessToken, params);
    }

    /**
     * 刷新页面access_token:使用refresh_token进行刷新页面access_token,
     * refresh_token有效期为30天，当refresh_token失效之后，需要用户重新授权
     * */
    public static RefreshTokenResp token2RefreshToken(RefreshTokenModel entity) {
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.getReq(new RefreshTokenResp(), WxMpApiType.RefreshToken, params);
    }

    /**
     * 拉取用户信息(需scope为 snsapi_userinfo)
     * 如果网页授权作用域为snsapi_userinfo，则此时开发者可以通过access_token和openid拉取用户信息了
     * */
    public static MpUserInfoResp userInfo(MpUserInfoModel entity) {
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.getReq(new MpUserInfoResp(), WxMpApiType.UserInfo, params);
    }

    /**
     * 页面access_token:检验授权凭证（access_token）是否有效
     * */
    public static CurrentAutoReplyInfoModel authAccessToken(AuthTokenModel entity) {
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.getReq(new CurrentAutoReplyInfoModel(), WxMpApiType.AuthToken, params);
    }

    /**
     * 获取公众号当前使用的自动回复规则
     * */
    public static BaseRespModel getCurrentAutoReplyInfo(String accessToken) {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("access_token", accessToken);
        return WxMpUtils.getReq(new BaseRespModel(), WxMpApiType.CurrentAutoReplyInfo, params);
    }

    public static void main(String[] args) {
//        AccessTokenModel entity=new AccessTokenModel();
//        entity.setAppid("wxe5bb3017fd108c5d");
//        entity.setSecret("c1d31167a5edc9c66772bea7009ee160");
//        AccessTokenResp data= WxMpApi.accessToken(entity);
//        System.out.println(JSON.toJSONString(data));

//        AccessTokenModel entity=new AccessTokenModel();
//        entity.setAppid("wx3cf98c292baf4eb3");
//        entity.setSecret("a91c7e01053d5c8f0cf278afd1dd3820");
//        AccessTokenResp data= WxMpApi.accessToken(entity);
//        System.out.println(JSON.toJSONString(data));


        String accessToken="64_eWXp2VeDgHt0tFmDH5hmS9X_1ogcBSSZhdTtZqmmUN5NIxtrWv_P8Am7mijdQyISmN7K4-9IBYjPZAhx2YN-SwiXTO4TESBH2ecOgWqi5_3V0PhBfOv6UIPRcXoXKGcAHACPL";

        String touser="oC3k75m9pIW3oqUuIJVVx9L4k_oM";
        String url="https://dev1.cloud-seal.com/1";

        String templateId="BIYRvHrU08dCa8I5G2tMSg1iIpm2NUgUq5iIHURw4nk";



        SendTempMsgModel sendTempMsgModel=new SendTempMsgModel();
//        sendTempMsgModel.setAccess_token(accessToken);
        sendTempMsgModel.setTemplate_id(templateId);
        sendTempMsgModel.setTouser(touser);
        sendTempMsgModel.setUrl(url);

//        sendTempMsgModel.addData("first.DATA","您测量的血压值上传成功，并为您生成健康报告。123");
//        sendTempMsgModel.addData("keyword1.DATA","2018年04月02日 12:12:23");// 报告时间
//        sendTempMsgModel.addData("keyword2.DATA","李正"); //会员名字
//        sendTempMsgModel.addData("keyword3.DATA","您在大庆路门店测量的血压值为120/78mmHg，血压值正常。"); //报告内容
//        sendTempMsgModel.addData("remark.DATA","怡适康为您服务。");


        sendTempMsgModel.addData("first","您测量的血压值上传成功，并为您生成健康报告。测试");
        sendTempMsgModel.addData("keyword1","2018年04月02日 12:12:23");// 报告时间
        sendTempMsgModel.addData("keyword2","李正"); //会员名字
        sendTempMsgModel.addData("keyword3","您在大庆路门店测量的血压值为120/78mmHg，血压值正常。"); //报告内容
        sendTempMsgModel.addData("remark","怡适康为您服务。");


//        Map<String, Object> params = BeanUtil.beanToMap(sendTempMsgModel, false, true);
//
//        System.out.println(JSON.toJSONString(sendTempMsgModel));

        SendTempMsgResp resp =WxMpMsgManageApi.sendTempMsg(accessToken,sendTempMsgModel);
        System.out.println(JSON.toJSONString(resp));




//        JsapiTicketModel entity=new JsapiTicketModel();
//        entity.setAccess_token("64_uH-1DY-K17Ie1zU-mU-vZY2ThAz8BLf4dIcD5SncmW93piT42S8S6D4WfaROgw5Kaj6_mz9gmHsz_oXQx2fbIBQItZtshh5uu9rbyf3Q8ydTiPiltbnj3dexUNcNCVhAFAIXQ");
//        JsapiTicketResp data= WxMpApi.jsapiTicket(entity);
//        System.out.println(JSON.toJSONString(data));

//        https://api.weixin.qq.com/cgi-bin/message/template/send?access_token=ACCESS_TOKEN


//        AccessTokenModel  entity=new AccessTokenModel();
//        entity.setAppid("wx3cf98c292baf4eb3");
//        entity.setSecret("a91c7e01053d5c8f0cf278afd1dd3820");
//        AccessTokenResp data= WxMpApi.accessToken(entity);
//        System.out.println(JSON.toJSONString(data));


//        WxJSSDKSignModel  data= WxJSSDKSignUtils.sign("wxe5bb3017fd108c5d",
//                "https://1.1.1.1/a/b","LIKLckvwlJT9cWIhEQTwfCQ6zhv6QRmCv457AO5PztytZ2Yg3N1U2lcIfKF6PXNz0OKzrs3UiS3qnkTLMpwvhg");
//        System.out.println(JSON.toJSONString(data));

    }



//
//    /**
//     * 获取用户基本信息
//     * */
//    public MpUserInfoResp getUserInfo(MpUserInfoModel params){
//        return null;
//    }


}
