package com.company.cloud.sdk.weixin.mp;

import cn.hutool.core.bean.BeanUtil;
import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.sdk.weixin.mp.enums.WxMpApiType;
import com.company.cloud.sdk.weixin.mp.model.media.*;
import com.company.cloud.sdk.weixin.mp.utils.WxMpUtils;

import java.util.Map;

/**
 * 微信公众号素材管理API
 */
public class WxMpMediaApi {

    /*******素材管理********/

    /**
     * 新增临时素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/New_temporary_materials.html
     */
    public static MediaUploadResp uploadMedia(MediaUploadModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MediaUploadResp(), WxMpApiType.MediaUpload, params);
    }

    /**
     * 获取（下载）临时素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_temporary_materials.html
     */
    public static MediaQueryResp getMedia(MediaQueryModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.getReq(new MediaQueryResp(), WxMpApiType.MediaGet, params);
    }

    /**
     * 获取（下载）高清语音素材
     * 公众号可以使用本接口获取从JSSDK的uploadVoice接口上传的临时语音素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_temporary_materials.html
     */
    public static MediaQueryResp getJssdkMedia(MediaQueryModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.getReq(new MediaQueryResp(), WxMpApiType.MediaJssdkGet, params);
    }

    /**
     * 新增永久图文素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Adding_Permanent_Assets.html
     */
    public static MateriaUploadResp addMaterialNews(MateriaUploadNewsModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MateriaUploadResp(), WxMpApiType.MaterialAddNews, params);
    }

    /**
     * 上传图文消息内的图片获取URL
     * 本接口所上传的图片不占用公众号的素材库中图片数量的100000个的限制。图片仅支持jpg/png格式，大小必须在1MB以下
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Adding_Permanent_Assets.html
     */
    public static MediaUploadImgResp uploadMediaImg(MateriaUploadImgModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MediaUploadImgResp(), WxMpApiType.MediaUploadImg, params);
    }

    /**
     * （群发）上传图文消息素材【订阅号与服务号认证后均可用】
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Message_Management/Batch_Sends_and_Originality_Checks.html
     */
    public static MediaUploadResp uploadMediaNews(MateriaUploadNewsModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MediaUploadResp(), WxMpApiType.MediaUploadNews, params);
    }

    /**
     * （群发）获取视频素材信息（此处media_id需通过素材管理->新增素材来得到）
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Message_Management/Batch_Sends_and_Originality_Checks.html
     */
    public static MediaUploadResp uploadMediaVideo(MateriaUploadVideoModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MediaUploadResp(), WxMpApiType.MediaUploadVideo, params);
    }

    /**
     * 新增其他类型永久素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Adding_Permanent_Assets.html
     */
    public static MateriaAddResp addMaterial(MediaUploadModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MateriaAddResp(), WxMpApiType.MaterialAdd, params);
    }

    /**
     * 新增视频永久素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Adding_Permanent_Assets.html
     */
    public static MateriaAddResp addVideoMaterial(MediaUploadVideoModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MateriaAddResp(), WxMpApiType.MaterialAdd, params);
    }

    /**
     * 获取永久素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Getting_Permanent_Assets.html
     */
    public static MateriaQueryResp getMaterial(MediaQueryModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MateriaQueryResp(), WxMpApiType.MaterialGet, params);
    }

    /**
     * 删除永久素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Deleting_Permanent_Assets.html
     */
    public static BaseRespModel delMaterial(MediaQueryModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.MaterialDel, params);
    }

    /**
     * 修改永久图文素材
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Editing_Permanent_Rich_Media_Assets.html
     */
    public static BaseRespModel updateMaterial(MateriaUpdateModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.MaterialUpdateNews, params);
    }

    /**
     * 获取永久素材总数
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_the_total_of_all_materials.html
     */
    public static MateriaQueryCountResp getMaterialCount(BaseReqModel baseEntity){
        Map<String, Object> params =  BeanUtil.beanToMap(baseEntity,false,true);
        return WxMpUtils.getReq(new MateriaQueryCountResp(), WxMpApiType.MaterialCount, params);
    }

    /**
     * 获取素材列表
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_materials_list.html
     */
    public static MateriaListResp getMaterialList(MateriaListModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MateriaListResp(), WxMpApiType.MaterialList, params);
    }

    /*******图文素材留言（评论）管理********/
    // 参考：https://developers.weixin.qq.com/doc/offiaccount/Comments_management/Image_Comments_Management_Interface.html

    /**
     * 打开已群发文章评论
     */
    public static BaseRespModel openComment(CommentReqModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.CommentOpen, params);
    }

    /**
     * 关闭已群发文章评论
     */
    public static BaseRespModel closeComment(CommentReqModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.CommentClose, params);
    }

    /**
     * 查看指定文章的评论数据
     */
    public static CommentListResp listComment(CommentListModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new CommentListResp(), WxMpApiType.CommentList, params);
    }

    /**
     * 将评论标记精选
     */
    public static BaseRespModel markelectComment(CommentIdReqModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.CommentMarkelect, params);
    }

    /**
     * 将评论取消精选
     * */
    public static BaseRespModel unmarkelectComment(CommentIdReqModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.CommentUnmarkelect, params);
    }

    /**
     * 删除评论
     * */
    public static BaseRespModel delComment(CommentIdReqModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.CommentDel, params);
    }

    /**
     * 回复评论
     * */
    public static BaseRespModel addReplyComment(CommentContentReqModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.CommentReplyAdd, params);
    }

    /**
     * 删除回复
     * */
    public static BaseRespModel delReplyComment(CommentIdReqModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.CommentReplyDel, params);
    }

}
