package com.company.cloud.sdk.weixin.mp;

import cn.hutool.core.bean.BeanUtil;
import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.sdk.weixin.mp.enums.WxMpApiType;
import com.company.cloud.sdk.weixin.mp.model.menu.*;
import com.company.cloud.sdk.weixin.mp.utils.WxMpUtils;


import java.util.Map;

/**
 * 微信公众号自定义菜单API
 */
public class WxMpMenuApi {

    /**
     * 创建自定义菜单
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Creating_Custom-Defined_Menu.html
     */
    public static BaseRespModel createMenu(MenuCreateModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.MenuCreate, params);
    }

    /**
     * 查询自定义菜单/个性化菜单
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Querying_Custom_Menus.html
     */
    public static MenuQueryResp queryMenu(BaseReqModel baseEntity){
        Map<String, Object> params =  BeanUtil.beanToMap(baseEntity,false,true);
        return WxMpUtils.getReq(new MenuQueryResp(), WxMpApiType.MenuQuery, params);
    }

    /**
     * 删除所有自定义菜单；在个性化菜单时，调用此接口会删除默认菜单及全部个性化菜单
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Deleting_Custom-Defined_Menu.html
     */
    public static BaseRespModel delMenu(BaseReqModel baseEntity){
        Map<String, Object> params =  BeanUtil.beanToMap(baseEntity,false,true);
        return WxMpUtils.getReq(new BaseRespModel(), WxMpApiType.MenuDelete, params);
    }

    /**
     * 个性化菜单接口
     * 参考：https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Personalized_menu_interface.html
     */
    /**
     * 创建个性化菜单
     */
    public static MenuMatchruleResp createPersonalizedMenu(MenuCreateModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MenuMatchruleResp(), WxMpApiType.PersonalizedMenuCreate, params);
    }

    /**
     * 删除个性化菜单
     */
    public static BaseRespModel delPersonalizedMenu(MenuPersonalizedDelModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.PersonalizedMenuDel, params);
    }

    /**
     * 测试个性化菜单
     */
    public static MenuModel testPersonalizedMenu(MenuPersonalizedTestModel entity){
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new MenuModel(), WxMpApiType.PersonalizedMenuTest, params);
    }

    /**
     * 获取自定义菜单配置
     */
    public static MenuGetModel getMenu(BaseReqModel baseEntity){
        Map<String, Object> params =  BeanUtil.beanToMap(baseEntity,false,true);
        return WxMpUtils.getReq(new MenuGetModel(), WxMpApiType.MenuGet, params);
    }

}
