package com.company.cloud.sdk.weixin.mp;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.sdk.weixin.mp.enums.WxMpApiType;
import com.company.cloud.sdk.weixin.mp.model.QRcodeWithParamsResp;
import com.company.cloud.sdk.weixin.mp.model.msgmanage.*;
import com.company.cloud.sdk.weixin.mp.utils.WxMpUtils;


import java.util.Map;

/**
 * 微信公众号消息管理API
 */
public class WxMpMsgManageApi {

    /**
     * 生成带参数的二维码
     * https://developers.weixin.qq.com/doc/offiaccount/Account_Management/Generating_a_Parametric_QR_Code.html
     */
    public static QRcodeWithParamsResp createQRCode( String accessToken, String params) {
        System.out.println("请求带参数的二维码参数>>>>>> " + params);
        String result = HttpUtil.post("https://api.weixin.qq.com/cgi-bin/qrcode/create?access_token=" + accessToken, params);
        System.out.println("带参数二维码数据<<<<<< " + result);
        return JSONObject.parseObject(result, QRcodeWithParamsResp.class);
    }

    /**
     * 发送模版消息
     * https://developers.weixin.qq.com/doc/offiaccount/Message_Management/Template_Message_Interface.html
     */
    public static SendTempMsgResp sendTempMsg( String accessToken ,SendTempMsgModel entity) {
        String url="https://api.weixin.qq.com/cgi-bin/message/template/send?access_token="+accessToken;
        String result = HttpRequest.post(url)
                .body(JSON.toJSONString(entity))
                .execute().body();

        System.out.println("1 : " + result);
        return WxMpUtils.convertResp(result,new SendTempMsgResp());
    }


    /**
     * 发送用户订阅的模版消息
     * 通过API推送订阅模板消息给到授权微信用户
     * https://developers.weixin.qq.com/doc/offiaccount/Message_Management/One-time_subscription_info.html
     */
    public static BaseRespModel subscribeTempMsg(SubscribeTempMsgModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.MsgTempSubscribe, params);
    }

    /**
     * 客服消息
     * https://developers.weixin.qq.com/doc/offiaccount/Message_Management/Service_Center_messages.html
     */
    /**
     * 添加客服帐号
     */
    public static BaseRespModel addKfAccount(KfAccountSetModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfAccountAdd, params);
    }

    /**
     * 修改客服帐号
     */
    public static BaseRespModel updateKfAccount(KfAccountSetModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfAccountUpdate, params);
    }

    /**
     * 删除客服帐号
     */
    public static BaseRespModel delKfAccount(KfAccountModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfAccountDel, params);
    }

    /**
     * 设置客服帐号的头像
     */
//    public static BaseRespModel setAccountImg(KfAccountModel entity) {
//        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
//        Map<String, Object> baseParams =  BeanUtil.beanToMap(baseEntity,false,true);
//        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfAccountHeadImg, params);
//    }

    /**
     * 获取所有客服账号
     */
    public static KfAccountResp queryKfList(BaseReqModel baseEntity) {
        Map<String, Object> params =  BeanUtil.beanToMap(baseEntity,false,true);
        return WxMpUtils.getReq(new KfAccountResp(), WxMpApiType.KfAccountList, params);
    }

    /**
     * 客服发送文本消息
     */
    public static BaseRespModel sendTextMsg(SendMsgTextModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }

    /**
     * 客服发送图片消息
     */
    public static BaseRespModel sendImgMsg(SendMsgImgModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }

    /**
     * 客服发送语音消息
     */
    public static BaseRespModel sendVoiceMsg(SendMsgVoiceModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }

    /**
     * 客服发送视频消息
     */
    public static BaseRespModel sendVideoMsg(SendMsgVideoModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }

    /**
     * 客服发送音乐消息
     */
    public static BaseRespModel sendMusicMsg(SendMsgMusicModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }

    /**
     * 客服发送图文消息（点击跳转到外链） 图文消息条数限制在1条以内
     */
    public static BaseRespModel sendNewsMsg(SendMsgNewsModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }

    /**
     * 客服发送图文消息（点击跳转到图文消息页面） 图文消息条数限制在1条以内
     */
    public static BaseRespModel sendMpNewsMsg(SendMsgMpNewsModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }
    
    /**
     * 客服发送菜单消息
     */
    public static BaseRespModel sendMenuMsg(SendMsgMenuModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }
    
    /**
     * 客服发送卡券
     */
    public static BaseRespModel sendWxcardMsg(SendMsgWxcardModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }
    
    /**
     * 客服发送小程序卡片（要求小程序与公众号已关联）
     */
    public static BaseRespModel sendMiniMsg(SendMsgMiniModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfMsgSend, params);
    }
    
    /**
     * 客服输入状态
     */
    public static BaseRespModel msgTyping(SendMsgTypingModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.KfTyping, params);
    }

    /**
     * 群发接口与原创校验
     * https://developers.weixin.qq.com/doc/offiaccount/Message_Management/Batch_Sends_and_Originality_Checks.html
     */
    /**
     * 根据标签群发图文消息
     */
    public static MassSendAllResp massSendAllMpNews(MassSendAllMpNewsModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSendAll, params);
    }

    /**
     * 根据标签群发文本消息
     */
    public static MassSendAllResp massSendAllText(MassSendAllTextModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSendAll, params);
    }

    /**
     * 根据标签群发语音/音频消息（注意此处media_id需通过素材管理->新增素材来得到）
     */
    public static MassSendAllResp massSendAllVoice(MassSendAllVoiceModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSendAll, params);
    }

    /**
     * 根据标签群发图片（注意此处media_id需通过素材管理->新增素材来得到）
     */
    public static MassSendAllResp massSendAllImg(MassSendAllImgModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSendAll, params);
    }

    /**
     * 根据标签群发视频
     * 此处视频的media_id需通过POST请求到下述接口特别地得到：
     * https://api.weixin.qq.com/cgi-bin/media/uploadvideo?access_token=ACCESS_TOKEN
     */
    public static MassSendAllResp massSendAllVideo(MassSendAllMpVideoModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSendAll, params);
    }

    /**
     * 根据标签群发卡券消息（注意图文消息的media_id需要通过上述方法来得到）
     */
    public static MassSendAllResp massSendAllWxcard(MassSendAllWxcardModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSendAll, params);
    }
    
    /**
     * 根据OpenID列表群发图文消息
     */
    public static MassSendAllResp massSendMpNews(MassSendMpNewsModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSend, params);
    }

    /**
     * 根据OpenID列表群发文本消息
     */
    public static MassSendAllResp massSendText(MassSendTextModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSend, params);
    }

    /**
     * 根据OpenID列表群发语音/音频消息（注意此处media_id需通过素材管理->新增素材来得到）
     */
    public static MassSendAllResp massSendVoice(MassSendVoiceModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSend, params);
    }

    /**
     * 根据OpenID列表群发图片（注意此处media_id需通过素材管理->新增素材来得到）
     */
    public static MassSendAllResp massSendImg(MassSendImgModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSend, params);
    }

    /**
     * 根据OpenID列表群发视频
     * 此处视频的media_id需通过POST请求到下述接口特别地得到：
     * https://api.weixin.qq.com/cgi-bin/media/uploadvideo?access_token=ACCESS_TOKEN
     */
    public static MassSendAllResp massSendVideo(MassSendMpVideoModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSend, params);
    }

    /**
     * 根据OpenID列表群发卡券消息（注意图文消息的media_id需要通过上述方法来得到）
     */
    public static MassSendAllResp massSendWxcard(MassSendWxcardModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassSend, params);
    }

    /**
     * 删除群发【订阅号与服务号认证后均可用】
     */
    public static BaseRespModel massDelWxcard(MassModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.MassDel, params);
    }
    // toto

    /**
     * 预览群发图文消息
     */
    public static MassSendAllResp massPreviewMpNews(MassPreviewMpNewsModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassPreview, params);
    }

    /**
     * 预览群发文本消息
     */
    public static MassSendAllResp massPreviewText(MassPreviewTextModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassPreview, params);
    }

    /**
     * 预览群发语音/音频消息（注意此处media_id需通过素材管理->新增素材来得到）
     */
    public static MassSendAllResp massPreviewVoice(MassPreviewVoiceModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassPreview, params);
    }

    /**
     * 预览群发图片（注意此处media_id需通过素材管理->新增素材来得到）
     */
    public static MassSendAllResp massPreviewImg(MassPreviewImgModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassPreview, params);
    }

    /**
     * 预览群发视频
     * 此处视频的media_id需通过POST请求到下述接口特别地得到：
     * https://api.weixin.qq.com/cgi-bin/media/uploadvideo?access_token=ACCESS_TOKEN
     */
    public static MassSendAllResp massPreviewVideo(MassPreviewMpVideoModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassPreview, params);
    }

    /**
     * 预览群发卡券消息（注意图文消息的media_id需要通过上述方法来得到）
     */
    public static MassSendAllResp massPreviewWxcard(MassPreviewWxcardModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSendAllResp(), WxMpApiType.MassPreview, params);
    }

    /**
     * 查询群发消息发送状态【订阅号与服务号认证后均可用】
     */
    public static MassStatusResp massStatus(MassModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassStatusResp(), WxMpApiType.MassStatus, params);
    }

    /**
     * 获取群发速度
     */
    public static MassSpeedResp massSpeedGet(BaseReqModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new MassSpeedResp(), WxMpApiType.MassSpeedGet, params);
    }

    /**
     * 设置群发速度
     */
    public static BaseRespModel massSpeedSet(MassSpeedModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.MassSpeedSet, params);
    }

}
