package com.company.cloud.sdk.weixin.mp;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.http.HttpUtil;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.company.cloud.sdk.weixin.common.constant.WxErrorEnum;
import com.company.cloud.sdk.weixin.common.exception.WxException;
import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.sdk.weixin.mp.enums.WxMpApiType;
import com.company.cloud.sdk.weixin.mp.model.usermanage.*;
import com.company.cloud.sdk.weixin.mp.utils.WxMpUtils;


import java.util.Map;

/**
 * 微信公众号用户管理API
 */
public class WxMpUserManageApi {

    /*******用户标签管理********/
    // 参考：https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html

    /**
     * 创建标签
     */
    public static TagResp createTag(TagHandleModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new TagResp(), WxMpApiType.TagCreate, params);
    }

    /**
     * 查询标签
     */
    public static TagListResp queryTag(BaseReqModel baseEntity) {
        Map<String, Object> params = BeanUtil.beanToMap(baseEntity, false, true);
        return WxMpUtils.getReq(new TagListResp(), WxMpApiType.TagGet, params);
    }

    /**
     * 编辑标签
     */
    public static BaseRespModel updateTag(TagHandleModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.TagUpdate, params);
    }

    /**
     * 删除标签
     */
    public static BaseRespModel delTag(TagHandleModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.TagDel, params);
    }

    /**
     * 获取标签下粉丝列表
     */
    public static TagUserResp queryTagUser(TagUserReqModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.getReq(new TagUserResp(), WxMpApiType.TagUserGet, params);
    }

    /**
     * 批量为用户打标签
     */
    public static BaseRespModel batchTagging(TagUserBatchTagReqModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.TagBatchTagging, params);
    }

    /**
     * 批量为用户取消标签
     */
    public static BaseRespModel batchUntagging(TagUserBatchTagReqModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.TagBatchUntagging, params);
    }

    /**
     * 获取用户身上的标签列表
     */
    public static TagUserListResp queryUserTags(TagUserModel entity) {
        Map<String, Object> params =  BeanUtil.beanToMap(entity,false,true);
        return WxMpUtils.postReq(new TagUserListResp(), WxMpApiType.TagGetIdList, params);
    }

    /*******设置用户备注名********/
    // 参考：https://developers.weixin.qq.com/doc/offiaccount/User_Management/Configuring_user_notes.html

    /**
     * 对指定用户设置备注名
     */
    public static BaseRespModel updateUserRemark(UserRemarkReqModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.UpdateUserRemark, params);
    }

    /**
     * 获取用户基本信息（包括UnionID机制）
     */
    public static UserBasicInfoResp getUserInfo(UserBasicInfoReqModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.getReq(new UserBasicInfoResp(), WxMpApiType.GetUserInfo, params);
    }

    /**
     * 批量获取用户基本信息
     */
    public static UserBasicInfoBatchResp batchGetUserInfo(UserBasicInfoBatchReqModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        try {
            String url = WxMpUtils.getReqUrl(WxMpApiType.BatchGetUserInfo) + "?access_token=" + entity.getAccess_token();
            // System.out.println("wechat user info >>>>>> : " + JSON.toJSONString(params));
            String httpResp = HttpUtil.post(url, JSON.toJSONString(params));
            // System.out.println("wechat <<<<<< : " + httpResp);
            UserBasicInfoBatchResp resp = JSONObject.parseObject(httpResp, UserBasicInfoBatchResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 获取帐号的关注者列表，关注者列表由一串OpenID组成
     */
    public static UserOpenidListResp listUserOpenid(UserOpenidListModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        try {
            String url = WxMpUtils.getReqUrl(WxMpApiType.ListUserOpenid);
            // System.out.println("wechat user openid >>>>>> : " + JSON.toJSONString(params));
            String httpResp = HttpUtil.get(url, params);
            UserOpenidListResp resp = JSONObject.parseObject(httpResp, UserOpenidListResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 获取公众号的黑名单列表
     */
    public static UserOpenidListResp blackList(UserBlackListModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.getReq(new UserOpenidListResp(), WxMpApiType.BlackList, params);
    }

    /**
     * 拉黑用户
     */
    public static BaseRespModel batchBlackList(UserBatchBlackListModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.BatchBlackList, params);
    }

    /**
     * 取消拉黑用户
     */
    public static BaseRespModel batchUnblackList(UserBatchBlackListModel entity) {
        Map<String, Object> params = BeanUtil.beanToMap(entity, false, true);
        return WxMpUtils.postReq(new BaseRespModel(), WxMpApiType.BatchUnblackList, params);
    }

}
