package com.company.cloud.sdk.weixin.mp.model.menu;

import com.company.cloud.sdk.weixin.mp.enums.WxMpMenuType;
import lombok.Getter;
import lombok.Setter;

import java.util.List;

/**
 * 查询自定义菜单button
 */
@Getter
@Setter
public class MenuQueryButtonModel {

    /**
     * 菜单的类型，公众平台官网上能够设置的菜单类型有view（跳转网页）、text（返回文本，下同）、
     * img、photo、video、voice。使用API设置的则有8种，详见《自定义菜单创建接口》
     */
    private WxMpMenuType type;

    /** 菜单标题，不超过16个字节，子菜单不超过60个字节 */
    private String name;

    /**
     * 对于不同的菜单类型，value的值意义不同。官网上设置的自定义菜单： 
     * Text:保存文字到value； Img、
     * voice：保存mediaID到value； 
     * Video：保存视频下载链接到value； 
     * News：保存图文消息到news_info，同时保存mediaID到value； 
     * View：保存链接到url。 
     * 使用API设置的自定义菜单： click、scancode_push、scancode_waitmsg、pic_sysphoto、pic_photo_or_album、 
     * pic_weixin、location_select：保存值到key；view：保存链接到url
     */
    private String value;
    private String url;
    private String key;

    /**图文消息的标题*/
    private String title;

    /**摘要*/
    private String digest;

    /**作者*/
    private String author;
    
    /**是否显示封面，0为不显示，1为显示*/
    private String show_cover;
    
    /**封面图片的URL*/
    private String cover_url;
    
    /**正文的URL*/
    private String content_url;
    
    /**原文的URL，若置空则无查看原文入口*/
    private String source_url;

    private List<MenuQueryButtonModel> list;
    
    /**图文消息的信息*/
    private MenuQueryButtonModel news_info;

    /** 二级菜单数组，个数应为1~5个 */
    private MenuQueryButtonModel sub_button;

}
