package com.company.cloud.sdk.weixin.mp.model.msgmanage;

import lombok.Getter;
import lombok.Setter;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * 接收事件推送通用字段
 * @author wing
 *
 */
@Getter
@Setter
@XmlAccessorType(XmlAccessType.FIELD)  
//XML文件中的根标识  
@XmlRootElement(name = "xml")
//控制JAXB 绑定类中属性和字段的排序  
@XmlType(propOrder = { 
   "toUserName",   
   "fromUserName",   
   "createTime",   
   "msgType", 
   "event",
   "eventKey",
   "ticket",
   "scanCodeInfo",
   "scanType",
   "scanResult"
})
public class ReceiveEventFullModel {

    /**
     * 开发者微信号/接收方帐号（收到的OpenID）
     */
    @XmlElement(name = "ToUserName")
    private String toUserName;

    /**
     * 发送方帐号（一个OpenID）/开发者微信号
     */
    @XmlElement(name = "FromUserName")
    private String fromUserName;

    /**
     * 消息创建时间 （整型）
     */
    @XmlElement(name = "CreateTime")
    private Long createTime;

    /**
     * 消息类型{WxMsgType}
     */
    @XmlElement(name = "MsgType")
    private String msgType;



    /**
     * 事件类型{WxMsgEventType}
     */
    @XmlElement(name = "Event")
    private String event;


    /**
     * 未关注用户扫描带参数二维码：事件KEY值，qrscene_为前缀，后面为二维码的参数值<span/>
     * 已关注用户扫描带参数二维码：是一个32位无符号整数，即创建二维码时的二维码scene_id
     */
    @XmlElement(name = "EventKey")
    private String eventKey;
    
    /**
     * 用户扫描带参数二维码<span/>
     * 二维码的ticket，可用来换取二维码图片
     */
    @XmlElement(name = "Ticket")
    private String ticket;



    /**
     * 扫描信息
     */
    @XmlElement(name = "ScanCodeInfo")
    private String scanCodeInfo;
    
    /**
     * 扫描类型，一般是qrcode
     */
    @XmlElement(name = "ScanType")
    private String scanType;
    
    /**
     * 扫描结果，即二维码对应的字符串信息
     */
    @XmlElement(name = "ScanResult")
    private String scanResult;
}
