package com.company.cloud.sdk.weixin.mp.model.msgmanage;

import lombok.Getter;
import lombok.Setter;

import javax.xml.bind.annotation.*;
import java.util.List;

/**
 * 在模版消息发送任务完成后，微信服务器会将是否送达成功作为通知，发送到开发者中心中填写的服务器配置地址中
 * 事件类型为TEMPLATESENDJOBFINISH
 * @author wing
 *
 */
@Getter
@Setter
@XmlAccessorType(XmlAccessType.FIELD)  
//XML文件中的根标识  
@XmlRootElement(name = "xml")  
//控制JAXB 绑定类中属性和字段的排序  
@XmlType(propOrder = {
   "msgID",
   "status"
})
public class ReceiveEventMassSendModel extends ReceiveEventModel {

    /**
     * 消息id
     */
    @XmlElement(name = "MsgID")
    private String msgID;

    /**
     * 发送状态
     * 群发的结果，为“send success”或“send fail”或“err(num)”。
     * 但send success时，也有可能因用户拒收公众号的消息、系统错误等原因造成少量用户接收失败。
     * err(num)是审核失败的具体原因，可能的情况如下：err(10001):涉嫌广告, err(20001):涉嫌政治, 
     * err(20004):涉嫌社会, err(20002):涉嫌色情, err(20006):涉嫌违法犯罪, err(20008):涉嫌欺诈, 
     * err(20013):涉嫌版权, err(22000):涉嫌互推(互相宣传), err(21000):涉嫌其他, 
     * err(30001):原创校验出现系统错误且用户选择了被判为转载就不群发, err(30002): 原创校验被判定为不能群发, 
     * err(30003): 原创校验被判定为转载文且用户选择了被判为转载就不群发, err(40001)：管理员拒绝, 
     * err(40002)：管理员30分钟内无响应，超时
     */
    @XmlElement(name = "Status")
    private String status;

    @XmlElement(name = "TotalCount")
    private String totalCount;
    
    @XmlElement(name = "FilterCount")
    private String filterCount;
    
    @XmlElement(name = "SentCount")
    private String sentCount;
    
    @XmlElement(name = "ErrorCount")
    private String errorCount;
    
    @XmlElement(name = "CopyrightCheckResult")
    private CopyrightCheckResult copyrightCheckResult;

    @XmlElement(name = "ArticleUrlResult")
    private ArticleUrlResult articleUrlResult;

    @Getter
    @Setter
    @XmlAccessorType(XmlAccessType.FIELD)  
    @XmlType(propOrder = { "count", "checkState", "resultList" })
    public static class CopyrightCheckResult {

        @XmlElement(name = "Count")
        private Integer count;

        @XmlElement(name = "CheckState")
        private Integer checkState;

        @XmlElement(name = "ResultList")
        private ResultList resultList;
    }

    @Getter
    @Setter
    @XmlAccessorType(XmlAccessType.FIELD)  
    @XmlType(propOrder = { "count", "resultList" })
    public static class ArticleUrlResult {
        @XmlElement(name = "Count")
        private Integer count;

        @XmlElement(name = "ResultList")
        private ResultList resultList;
    }

    @Getter
    @Setter
    @XmlAccessorType(XmlAccessType.FIELD)  
    @XmlType(propOrder = { "item" })
    public static class ResultList {
        @XmlElement(name = "item")
        private List<Item> item;

        @Getter
        @Setter
        @XmlAccessorType(XmlAccessType.FIELD)  
        @XmlType(propOrder = { 
                "articleIdx",
                "articleUrl", 
                "userDeclareState", 
                "auditState", 
                "originalArticleUrl",
                "originalArticleType",
                "canReprint",
                "needReplaceContent",
                "nedShowReprintSource",
        })
        public static class Item {
            @XmlElement(name = "ArticleIdx")
            private Integer articleIdx;

            @XmlElement(name = "ArticleUrl")
            private String articleUrl;

            @XmlElement(name = "UserDeclareState")
            private Integer userDeclareState;

            @XmlElement(name = "AuditState")
            private Integer auditState;

            @XmlElement(name = "OriginalArticleUrl")
            private String originalArticleUrl;

            @XmlElement(name = "OriginalArticleType")
            private Integer originalArticleType;

            @XmlElement(name = "CanReprint")
            private Integer canReprint;

            @XmlElement(name = "NeedReplaceContent")
            private Integer needReplaceContent;

            @XmlElement(name = "NeedShowReprintSource")
            private Integer nedShowReprintSource;
        }
    }
}
