package com.company.cloud.sdk.weixin.mp.model.msgmanage;

import lombok.Getter;
import lombok.Setter;

import javax.xml.bind.annotation.*;
import java.util.List;

/**
 * 回复图文消息
 * @author wing
 *
 */
@Getter
@Setter
@XmlAccessorType(XmlAccessType.FIELD)  
//XML文件中的根标识  
@XmlRootElement(name = "xml")  
//控制JAXB 绑定类中属性和字段的排序  
@XmlType(propOrder = {   
   "articleCount",   
   "articles",   
})
public class ReplyMsgNewsModel extends MsgModel {

    /**
     * 图文消息个数；当用户发送文本、图片、语音、视频、图文、地理位置这六种消息时，开发者只能回复1条图文消息；
     * 其余场景最多可回复8条图文消息
     */
    @XmlElement(name = "ArticleCount")
    private Integer articleCount;
    
    /**
     * 图文消息信息，注意，如果图文数超过限制，则将只发限制内的条数
     */
    @XmlElement(name = "Articles")
    private Articles articles;

    @Getter
    @Setter
    @XmlAccessorType(XmlAccessType.FIELD)  
    @XmlType(propOrder = {"item"})
    public static class Articles {
        // 音乐标题
        @XmlElement(name = "item")
        private List<Item> item;
    }

    @Getter
    @Setter
    @XmlAccessorType(XmlAccessType.FIELD)  
    @XmlType(propOrder = {"title", "description", "picUrl", "url"})
    public static class Item {
        // 图文消息标题
        @XmlElement(name = "Title")
        private String title;
        // 图文消息描述
        @XmlElement(name = "Description")
        private String description;
        // 图片链接，支持JPG、PNG格式，较好的效果为大图360*200，小图200*200
        @XmlElement(name = "PicUrl")
        private String picUrl;
        // 点击图文消息跳转链接
        @XmlElement(name = "Url")
        private String url;
    }
}
