package com.company.cloud.wx.sdk.work.inner;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.company.cloud.sdk.weixin.common.constant.WxErrorEnum;
import com.company.cloud.sdk.weixin.common.exception.WxException;
import com.company.cloud.wx.sdk.work.enums.WxWorkApiType;
import com.company.cloud.wx.sdk.work.enums.WxWorkDomain;
import com.company.cloud.wx.sdk.work.inner.model.Authorize2CodeModel;
import com.company.cloud.wx.sdk.work.inner.model.Code2TicketModel;
import com.company.cloud.wx.sdk.work.inner.model.Ticket2UserInfoModel;
import com.company.cloud.wx.sdk.work.inner.model.Ticket2UserInfoResp;
import com.company.cloud.wx.sdk.work.inner.model.Code2TicketResp;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendFileModel;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendMarkdownModel;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendMpNewsModel;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendNewsModel;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendTextModel;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendVideoModel;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendVoiceModel;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendResp;
import com.company.cloud.wx.sdk.work.inner.model.MessageSendTextCardModel;

import cn.hutool.core.util.URLUtil;
import cn.hutool.http.HttpUtil;

/**
 * 企业微信内部开发
 */
public class WxWorkInnerApi {

    /**
     * 构造网页授权链接
     */
    public static String authorize2Code(Authorize2CodeModel entity) {
        String url = WxWorkDomain.AUTH.getType() + WxWorkApiType.Authorize2Code.getType();
        String path = url.concat("?appid="+entity.getAppId()+"&redirect_uri="+URLUtil.encodeAll(entity.getRedirectUri())+"&response_type=code&scope="+entity.getScope()+"&state="+entity.getState()+"&agentid="+entity.getAgentId()+"#wechat_redirect");
        return path;
    }

    /**
     * 获取访问用户身份
     */
    public static Code2TicketResp getUserInfo(Code2TicketModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.GetUserInfo.getType() + "?access_token=" + entity.getAccess_token() + "&code=" + entity.getCode();
            String httpResp = HttpUtil.get(url);
            Code2TicketResp resp = JSONObject.parseObject(httpResp, Code2TicketResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 获取访问用户敏感信息
     */
    public static Ticket2UserInfoResp getUserDetail(Ticket2UserInfoModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.GetUserDetail.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            Ticket2UserInfoResp resp = JSONObject.parseObject(httpResp, Ticket2UserInfoResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * 文本消息
     */
    public static MessageSendResp messageSendText(MessageSendTextModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * 图片消息
     */
    public static MessageSendResp messageSendImage(MessageSendTextModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * 语音消息
     */
    public static MessageSendResp messageSendVoice(MessageSendVoiceModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * 视频消息
     */
    public static MessageSendResp messageSendVideo(MessageSendVideoModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * 文件消息
     */
    public static MessageSendResp messageSendFile(MessageSendFileModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * 文本卡片
     */
    public static MessageSendResp messageSendTextcard(MessageSendTextCardModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * 图文（图片存储在企业微信外部）
     */
    public static MessageSendResp messageSendNews(MessageSendNewsModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * 图文（图片存储在企业微信内部）
     */
    public static MessageSendResp messageSendMpNews(MessageSendMpNewsModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }

    /**
     * 发送应用消息
     * markdown
     */
    public static MessageSendResp messageSendMarkdown(MessageSendMarkdownModel entity) {
        try {
            String url = WxWorkDomain.QY.getType() + WxWorkApiType.MessageSend.getType() + "?access_token=" + entity.getAccess_token();
            String httpResp = HttpUtil.post(url, JSON.toJSONString(entity));
            MessageSendResp resp = JSONObject.parseObject(httpResp, MessageSendResp.class);
            if (resp.getErrcode() != null && resp.getErrcode() != 0) {
                throw new WxException(resp.getErrcode(), resp.getErrmsg());
            }
            return resp;
        }catch (Exception e){
            throw new WxException(WxErrorEnum.WX_Http_ERROR.getCode(),e.getMessage());
        }
    }



}
