package com.company.cloud.wx.sdk.work.inner.model;

import java.util.List;

import com.company.cloud.sdk.weixin.common.model.BaseReqModel;

import lombok.Getter;
import lombok.Setter;

// touser、toparty、totag不能同时为空
@Getter
@Setter
public class MessageSendNewsModel extends BaseReqModel {

    // 指定接收消息的成员，成员ID列表（多个接收者用‘|’分隔，最多支持1000个）。
    // 特殊情况：指定为"@all"，则向该企业应用的全部成员发送
    private String touser;

    // 指定接收消息的部门，部门ID列表，多个接收者用‘|’分隔，最多支持100个。
    // 当touser为"@all"时忽略本参数
    private String toparty;

    // 指定接收消息的标签，标签ID列表，多个接收者用‘|’分隔，最多支持100个。
    // 当touser为"@all"时忽略本参数
    private String totag;

    // 消息类型，此时固定为：news
    // @NotNull
    private String msgtype;

    // 企业应用的id，整型。企业内部开发，可在应用的设置页面查看；第三方服务商，可通过接口 获取企业授权信息 获取该参数值
    // @NotNull
    private Long agentid;

    // 消息内容
    // @NotNull
    private News news;

    // 表示是否是保密消息，0表示可对外分享，1表示不能分享且内容显示水印，默认为0
    private String safe;

    // 表示是否开启id转译，0表示否，1表示是，默认0。仅第三方应用需要用到，企业自建应用可以忽略。
    private String enable_id_trans;

    // 表示是否开启重复消息检查，0表示否，1表示是，默认0
    private String enable_duplicate_check;

    // 表示是否重复消息检查的时间间隔，默认1800s，最大不超过4小时
    private String duplicate_check_interval;

    /**
     * 消息内容
     */
    @Getter
    @Setter
    public static class News {
        // 图文消息，一个图文消息支持1到8条图文
        private List<NewsArticle> articles;
    }

    /**
     * 消息内容
     */
    @Getter
    @Setter
    public static class NewsArticle {
        // 标题，不超过128个字节，超过会自动截断（支持id转译）
        private String title;
        // 描述，不超过512个字节，超过会自动截断（支持id转译）
        private String description;
        // 点击后跳转的链接。 最长2048字节，请确保包含了协议头(http/https)，小程序或者url必须填写一个
        private String url;
        // 图文消息的图片链接，最长2048字节，支持JPG、PNG格式，较好的效果为大图 1068*455，小图150*150。
        private String picurl;
        // 小程序appid，必须是与当前应用关联的小程序，appid和pagepath必须同时填写，填写后会忽略url字段
        private String appid;
        // 点击消息卡片后的小程序页面，最长128字节，仅限本小程序内的页面。appid和pagepath必须同时填写，填写后会忽略url字段
        private String pagepath;
    }
}
