package com.company.cloud.wx.sdk.work.model;

import lombok.Getter;
import lombok.Setter;

import java.util.List;

@Getter
@Setter
public class ExternalProfileModel {

    /**
     * 企业对外简称，需从已认证的企业简称中选填。可在“我的企业”页中查看企业简称认证状态。
     */
    private String external_corp_name;

    /**
     * 属性列表，目前支持文本、网页、小程序三种类型
     */
    private List<String> external_attr;

    /**
     * text、web、miniprogram三者只能出现一种
     */
    @Getter
    @Setter
    public class Attr {

        /**
         * 属性类型: 0-文本 1-网页 2-小程序
         */
        private String type;

        /**
         * 属性名称： 需要先确保在管理端有创建该属性，否则会忽略
         */
        private String name;

        /**
         * 文本类型的属性
         */
        private Text text;

        /**
         * 网页类型的属性，url和title字段要么同时为空表示清除该属性，要么同时不为空
         */
        private Web web;

        /**
         * 小程序类型的属性，appid和title字段要么同时为空表示清除该属性，要么同时不为空
         */
        private MiniProgram miniprogram;
    }

    @Getter
    @Setter
    public class Text {

        /**
         * 文本属性内容,长度限制12个UTF8字符
         */
        private String value;
    }

    @Getter
    @Setter
    public class Web {

        /**
         * 网页的展示标题,长度限制12个UTF8字符
         */
        private String title;

        /**
         * 网页的url,必须包含http或者https头
         */
        private String url;
    }

    @Getter
    @Setter
    public class MiniProgram {

        /**
         * 小程序appid，必须是有在本企业安装授权的小程序，否则会被忽略
         */
        private String appid;

        /**
         * 小程序的展示标题,长度限制12个UTF8字符
         */
        private String title;

        /**
         * 小程序的页面路径
         */
        private String pagepath;
    }
}
