package com.company.cloud.wx.sdk.work.model.externalcontact;

import lombok.Getter;
import lombok.Setter;

/**
 * 结束语定义:
 * text、image、link和miniprogram四者不能同时为空；
 * text与另外三者可以同时发送，此时将会以两条消息的形式触达客户;
 * image、link和miniprogram只能有一个，如果三者同时填，则按image、link、miniprogram的优先顺序取参，
 * 也就是说，如果image与link同时传值，则只有image生效;
 * media_id可以通过素材管理接口获得;
 * 构造结束语使用image消息时，只能填写meida_id字段,获取含有image结构的联系我方式时，返回pic_url字段。
 */
@Getter
@Setter
public class MsgTypeModel {

    private Text text;

    private Image image;

    private Link link;

    private Miniprogram miniprogram;

    private File file;

    private Video video;

    @Getter
    @Setter
    public static class Text {

        /**
         * 消息文本内容,最长为4000字节
         */
        private String content;
    }

    @Getter
    @Setter
    public static class Image {

        /**
         * 图片的media_id
         */
        private String media_id;

        /**
         * 图片的url
         */
        private String pic_url;
    }

    @Getter
    @Setter
    public static class Link {

        /**
         * 图文消息标题，最长为128字节
         */
        private String title;

        /**
         * 图文消息封面的url
         */
        private String picurl;

        /**
         * 图文消息的描述，最长为512字节
         */
        private String desc;

        /**
         * 图文消息的链接
         */
        private String url;
    }

    @Getter
    @Setter
    public static class Miniprogram {

        /**
         * 小程序消息标题，最长为64字节
         */
        private String title;

        /**
         * 小程序消息封面的mediaid，封面图建议尺寸为520*416
         */
        private String pic_media_id;

        /**
         * 小程序appid，必须是关联到企业的小程序应用
         */
        private String appid;

        /**
         * 小程序page路径
         */
        private String page;
    }

    @Getter
    @Setter
    public static class File {

        /**
         * 视频的media_id，可以通过获取临时素材下载资源
         */
        private String media_id;
    }

    @Getter
    @Setter
    public static class Video {

        /**
         * 视频的media_id，可以通过获取临时素材下载资源
         */
        private String media_id;
    }

}
