package com.company.cloud.wx.sdk.work.model.externalcontact.tag;

import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import lombok.Getter;
import lombok.Setter;

import java.util.List;

/**
 * 如果要向指定的标签组下添加标签，需要填写group_id参数；如果要创建一个全新的标签组以及标签，则需要通过group_name参数指定新标签组名称，如果填写的groupname已经存在，则会在此标签组下新建标签。
 * 如果填写了group_id参数，则group_name和标签组的order参数会被忽略。
 * 不支持创建空标签组。
 * 标签组内的标签不可同名，如果传入多个同名标签，则只会创建一个。
 */
@Getter
@Setter
public class TagAddReqModel extends BaseReqModel {

    /**
     * 标签组id
     * 非必传
     */
    private String group_id;

    /**
     * 标签组名称，最长为30个字符
     * 非必传
     */
    private String group_name;

    /**
     * 标签组次序值。order值大的排序靠前。有效的值范围是[0, 2^32)
     * 非必传
     */
    private Integer order;

    /**
     * 添加的标签信息
     * 非必传
     */
    private List<Tag> tag;

    /**
     * 授权方安装的应用agentid。仅旧的第三方多应用套件需要填此参数
     * 非必传
     */
    private Integer agentid;

    @Getter
    @Setter
    public static class Tag {

        /**
         * 添加的标签名称，最长为30个字符
         * 必传
         */
        private String name;

        /**
         * 标签次序值。order值大的排序靠前。有效的值范围是[0, 2^32)
         */
        private Integer order;
    }
}
