package com.company.cloud.wx.sdk.work.third;

import com.company.cloud.wx.sdk.work.enums.WxWorkCustomerApiType;
import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.wx.sdk.work.model.externalcontact.FollowUserResp;
import com.company.cloud.wx.sdk.work.model.externalcontact.contact.*;
import com.company.cloud.wx.sdk.work.model.externalcontact.customer.*;
import com.company.cloud.wx.sdk.work.model.externalcontact.groupchat.GroupChatInfoReqModel;
import com.company.cloud.wx.sdk.work.model.externalcontact.groupchat.GroupChatInfoResp;
import com.company.cloud.wx.sdk.work.model.externalcontact.groupchat.GroupChatListReqModel;
import com.company.cloud.wx.sdk.work.model.externalcontact.groupchat.GroupChatListResp;
import com.company.cloud.wx.sdk.work.model.externalcontact.message.*;
import com.company.cloud.wx.sdk.work.model.externalcontact.moment.*;
import com.company.cloud.wx.sdk.work.model.externalcontact.statistic.StatisticGroupReqModel;
import com.company.cloud.wx.sdk.work.model.externalcontact.statistic.StatisticGroupResp;
import com.company.cloud.wx.sdk.work.model.externalcontact.statistic.StatisticUserReqModel;
import com.company.cloud.wx.sdk.work.model.externalcontact.statistic.StatisticUserResp;
import com.company.cloud.wx.sdk.work.model.externalcontact.tag.*;
import com.company.cloud.wx.sdk.work.model.externalcontact.transfer.*;
import com.company.cloud.wx.sdk.work.utils.WxWorkUtils;

/**
 * 企业微信客户管理API（三方应用开发）
 */
public class WxWorkThirdCustomerApi {

    /*******企业服务人员管理********/

    /**
     * 获取配置了客户联系功能的成员列表
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/92571
     */
    public static FollowUserResp followUserList(BaseReqModel entity) {
        return WxWorkUtils.getReq(new FollowUserResp(), WxWorkCustomerApiType.FOLLOW_USER_LIST.getType(), entity);
    }

    /**
     * 客户联系「联系我」管理
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/92572
     */

    /**
     * 配置客户联系「联系我」方式
     */
    public static ContactAddResp addContactWay(ContactSetModel entity) {
        return WxWorkUtils.postReq(new ContactAddResp(), WxWorkCustomerApiType.ADD_CONTACT_WAY.getType(), entity);
    }

    /**
     * 获取企业已配置的「联系我」方式
     */
    public static ContactGetResp getContactWay(ContactReqModel entity) {
        return WxWorkUtils.postReq(new ContactGetResp(), WxWorkCustomerApiType.GET_CONTACT_WAY.getType(), entity);
    }

    /**
     * 更新企业已配置的「联系我」方式
     */
    public static BaseRespModel updateContactWay(ContactSetModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.UPDATE_CONTACT_WAY.getType(), entity);
    }

    /**
     * 删除企业已配置的「联系我」方式
     */
    public static BaseRespModel delContactWay(ContactReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.DEL_CONTACT_WAY.getType(), entity);
    }

    /**
     * 结束临时会话
     */
    public static BaseRespModel closeChat(ConclusionsReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.CLOSE_CHAT.getType(), entity);
    }

    /**
     * 客户管理
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/92112
     */

    /**
     * 获取客户列表
     */
    public static CustomerListResp customerList(CustomerListReqModel entity) {
        return WxWorkUtils.getReq(new CustomerListResp(), WxWorkCustomerApiType.CUSTOMER_LIST.getType(), entity);
    }

    /**
     * 获取客户详情
     */
    public static CustomerInfoResp customerInfo(CustomerInfoReqModel entity) {
        return WxWorkUtils.getReq(new CustomerInfoResp(), WxWorkCustomerApiType.CUSTOMER_GET.getType(), entity);
    }

    /**
     * 批量获取客户详情
     */
    public static CustomerInfoBatchResp customerInfoBatch(CustomerInfoBatchReqModel entity) {
        return WxWorkUtils.postReq(new CustomerInfoBatchResp(), WxWorkCustomerApiType.CUSTOMER_BATCH_GET.getType(), entity);
    }

    /**
     * 修改客户备注信息
     */
    public static BaseRespModel remarkCustomer(CustomerRemarkReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.CUSTOMER_REMARK.getType(), entity);
    }

    /**
     * 获取手机号随机串
     * 该随机串可直接在企业微信终端搜索手机号对应的微信用户。
     */
    public static MobileHashCodeResp getMobileHashCode(MobileHashCodeReqModel entity) {
        return WxWorkUtils.postReq(new MobileHashCodeResp(), WxWorkCustomerApiType.CUSTOMER_MOBILE_HASHCODE.getType(), entity);
    }

    /**
     * 客户标签管理
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/92116
     */

    /**
     * 获取企业标签库
     */
    public static TagListResp tagList(TagListReqModel entity) {
        return WxWorkUtils.postReq(new TagListResp(), WxWorkCustomerApiType.CUSTOMER_TAG_LIST.getType(), entity);
    }

    /**
     * 添加企业客户标签
     * 企业可通过此接口向客户标签库中添加新的标签组和标签，每个企业最多可配置3000个企业标签。
     */
    public static TagAddResp tagAdd(TagAddReqModel entity) {
        return WxWorkUtils.postReq(new TagAddResp(), WxWorkCustomerApiType.CUSTOMER_TAG_ADD.getType(), entity);
    }

    /**
     * 编辑企业客户标签
     */
    public static BaseRespModel tagUpdate(TagUpdateReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.CUSTOMER_TAG_UPDATE.getType(), entity);
    }

    /**
     * 删除企业客户标签
     */
    public static BaseRespModel tagDel(TagDelReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.CUSTOMER_TAG_DEL.getType(), entity);
    }

    /**
     * 编辑客户企业标签
     * 企业可通过此接口为指定成员的客户添加上由企业统一配置的标签。
     */
    public static BaseRespModel tagMark(TagMarkReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.CUSTOMER_TAG_MARK.getType(), entity);
    }

    /**
     * 客户分配
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/92123
     */

    /**
     * 分配在职成员的客户
     * 企业可通过此接口，转接在职成员的客户给其他成员。
     */
    public static TransferCustomerResp transferCustomer(TransferCustomerReq entity) {
        return WxWorkUtils.postReq(new TransferCustomerResp(), WxWorkCustomerApiType.TRANSFER_CUSTOMER.getType(), entity);
    }

    /**
     * 查询客户接替状态(在职继承)
     * 企业和第三方可通过此接口查询在职成员的客户转接情况。
     */
    public static TransferResultResp transferResult(TransferResultReq entity) {
        return WxWorkUtils.postReq(new TransferResultResp(), WxWorkCustomerApiType.TRANSFER_RESULT.getType(), entity);
    }

    /**
     * 获取离职成员列表
     * 企业和第三方可通过此接口，获取所有离职成员的客户列表，并可进一步调用分配在职或离职成员的客户接口将这些客户重新分配给其他企业成员。
     */
    public static UnassignedListResp unassignedList(UnassignedListReqModel entity) {
        return WxWorkUtils.postReq(new UnassignedListResp(), WxWorkCustomerApiType.TRANSFER_USER_LIST.getType(), entity);
    }

    /**
     * 分配离职成员的客户群
     * 企业可通过此接口，将已离职成员为群主的群，分配给另一个客服成员。
     */
    public static TransferGroupResp transferGroup(TransferGroupReqModel entity) {
        return WxWorkUtils.postReq(new TransferGroupResp(), WxWorkCustomerApiType.TRANSFER_GROUP.getType(), entity);
    }

    /**
     * 分配离职成员的客户
     * 企业可通过此接口，转接在职成员的客户给其他成员。
     */
    public static TransferCustomerResp resignedTransferCustomer(ResignedTransferCustomerReq entity) {
        return WxWorkUtils.postReq(new TransferCustomerResp(), WxWorkCustomerApiType.RESIGNED_TRANSFER_CUSTOMER.getType(), entity);
    }

    /**
     * 查询客户接替状态(离职继承)
     * 企业和第三方可通过此接口查询在职成员的客户转接情况。
     */
    public static TransferResultResp resignedTransferResult(TransferResultReq entity) {
        return WxWorkUtils.postReq(new TransferResultResp(), WxWorkCustomerApiType.RESIGNED_TRANSFER_RESULT.getType(), entity);
    }

    /**
     * 分配在职或离职成员的客户 (原接口分配在职或离职成员的客户后续将不再更新维护，请使用新接口)
     * 企业可通过此接口，转接在职成员的客户或分配离职成员的客户给其他成员。
     */
    public static BaseRespModel transfer(TransferReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.TRANSFER_USER.getType(), entity);
    }

    /**
     * 获取客户群列表
     * 该接口用于获取配置过客户群管理的客户群列表。
     */
    public static GroupChatListResp groupChatList(GroupChatListReqModel entity) {
        return WxWorkUtils.postReq(new GroupChatListResp(), WxWorkCustomerApiType.GROUP_LIST.getType(), entity);
    }

    /**
     * 获取客户群详情
     * 通过客户群ID，获取详情。包括群名、群成员列表、群成员入群时间、入群方式。（客户群是由具有客户群使用权限的成员创建的外部群）
     * 需注意的是，如果发生群信息变动，会立即收到群变更事件，但是部分信息是异步处理，可能需要等一段时间调此接口才能得到最新结果
     */
    public static GroupChatInfoResp groupChatInfo(GroupChatInfoReqModel entity) {
        return WxWorkUtils.postReq(new GroupChatInfoResp(), WxWorkCustomerApiType.GROUP_GET.getType(), entity);
    }

    /**
     * 客户朋友圈
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/93332
     */

    /**
     * 获取企业全部的发表列表
     */
    public static MomentListResp momentList(MomentListReqModel entity) {
        return WxWorkUtils.postReq(new MomentListResp(), WxWorkCustomerApiType.MOMENT_LIST.getType(), entity);
    }

    /**
     * 获取客户朋友圈企业发表的列表
     */
    public static MomentTaskResp momentTask(MomentTaskReqModel entity) {
        return WxWorkUtils.postReq(new MomentTaskResp(), WxWorkCustomerApiType.MOMENT_TASK.getType(), entity);
    }

    /**
     * 获取客户朋友圈发表时选择的可见范围
     */
    public static MomentCustomerListResp momentCustomerList(MomentCustomerListReqModel entity) {
        return WxWorkUtils.postReq(new MomentCustomerListResp(), WxWorkCustomerApiType.MOMENT_CUSTOMER_LIST.getType(), entity);
    }

    /**
     * 获取客户朋友圈发表后的可见客户列表
     */
    public static MomentCustomerListResp momentResultList(MomentCustomerListReqModel entity) {
        return WxWorkUtils.postReq(new MomentCustomerListResp(), WxWorkCustomerApiType.MOMENT_RESULT.getType(), entity);
    }

    /**
     * 获取客户朋友圈的互动数据
     */
    public static MomentCommentResp momentComments(MomentCommentReqModel entity) {
        return WxWorkUtils.postReq(new MomentCommentResp(), WxWorkCustomerApiType.MOMENT_COMMENTS.getType(), entity);
    }

    /**
     * 消息推送
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/92134
     */

    /**
     * 创建企业群发
     */
    public static MsgTemplateResp addTemplateMsg(MsgTemplateReqModel entity) {
        return WxWorkUtils.postReq(new MsgTemplateResp(), WxWorkCustomerApiType.MSG_ADD.getType(), entity);
    }

    /**
     * 获取群发记录列表
     */
    public static GroupMsgListResp groupMsgList(GroupMsgListReqModel entity) {
        return WxWorkUtils.postReq(new GroupMsgListResp(), WxWorkCustomerApiType.MSG_LIST.getType(), entity);
    }

    /**
     * 获取群发成员发送任务列表
     */
    public static GroupMsgTaskResp groupMsgTask(GroupMsgTaskReqModel entity) {
        return WxWorkUtils.postReq(new GroupMsgTaskResp(), WxWorkCustomerApiType.MSG_TASK.getType(), entity);
    }

    /**
     * 获取企业群发成员执行结果
     */
    public static GroupMsgResp groupMsgResult(GroupMsgReqModel entity) {
        return WxWorkUtils.postReq(new GroupMsgResp(), WxWorkCustomerApiType.MSG_RESULT.getType(), entity);
    }

    /**
     * 发送新客户欢迎语
     */
    public static BaseRespModel welcomeMsgSend(WelcomeMsgSendReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.MSG_WELCOME_SEND.getType(), entity);
    }

    /**
     * 添加入群欢迎语素材
     */
    public static WelcomeMsgAddResp addWelcomeMsg(WelcomeMsgAddReqModel entity) {
        return WxWorkUtils.postReq(new WelcomeMsgAddResp(), WxWorkCustomerApiType.MSG_WELCOME_ADD.getType(), entity);
    }

    /**
     * 编辑入群欢迎语素材
     */
    public static BaseRespModel updateWelcomeMsg(WelcomeMsgUpdateReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.MSG_WELCOME_UPDATE.getType(), entity);
    }

    /**
     * 获取入群欢迎语素材
     */
    public static WelcomeMsgGetResp getWelcomeMsg(WelcomeMsgGetReqModel entity) {
        return WxWorkUtils.postReq(new WelcomeMsgGetResp(), WxWorkCustomerApiType.MSG_WELCOME_GET.getType(), entity);
    }

    /**
     * 删除入群欢迎语素材
     */
    public static BaseRespModel delWelcomeMsg(WelcomeMsgDelReqModel entity) {
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkCustomerApiType.MSG_WELCOME_DEL.getType(), entity);
    }

    /**
     * 统计管理
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/92131
     */

    /**
     * 获取「联系客户统计」数据
     */
    public static StatisticUserResp statisticUser(StatisticUserReqModel entity) {
        return WxWorkUtils.postReq(new StatisticUserResp(), WxWorkCustomerApiType.STATISTIC_USER.getType(), entity);
    }

    /**
     * 获取「群聊数据统计」数据
     */
    public static StatisticGroupResp statisticGroup(StatisticGroupReqModel entity) {
        return WxWorkUtils.postReq(new StatisticGroupResp(), WxWorkCustomerApiType.STATISTIC_GROUP.getType(), entity);
    }

    /**
     * 按自然日聚合的方式获取「群聊数据统计」数据
     */
    public static StatisticGroupResp statisticGroupByDay(StatisticGroupReqModel entity) {
        return WxWorkUtils.postReq(new StatisticGroupResp(), WxWorkCustomerApiType.STATISTIC_GROUP_BY_DAY.getType(), entity);
    }

    // TODO
}
