package com.company.cloud.wx.sdk.work.third;

import com.company.cloud.sdk.weixin.common.model.BaseReqModel;
import com.company.cloud.sdk.weixin.common.model.BaseRespModel;
import com.company.cloud.wx.sdk.work.enums.WxWorkAddressBookApiType;
import com.company.cloud.wx.sdk.work.model.department.*;
import com.company.cloud.wx.sdk.work.model.member.*;
import com.company.cloud.wx.sdk.work.model.tag.*;
import com.company.cloud.wx.sdk.work.utils.WxWorkUtils;

import javax.validation.Valid;

/**
 * 企业微信成员管理API（三方应用开发）
 */
public class WxWorkThirdMemberManageApi {
    /*******成员管理********/

    /**
     * 创建成员
     * 参考：https://work.weixin.qq.com/api/doc/90001/90143/90331
     */
    public static MemberCreateResp createMember(@Valid MemberCreateModel entity) {
        return WxWorkUtils.postReq(new MemberCreateResp(), WxWorkAddressBookApiType.Create_Member.getType(), entity);

    }

    /**
     * 读取成员
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90196
     */
    public static MemberGetResp getMember(@Valid MemberGetModel entity) {
        return WxWorkUtils.getReq(new MemberGetResp(), WxWorkAddressBookApiType.Get_Member.getType(), entity);
    }

    /**
     * 更新成员
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90197
     */
    public static MemberUpdateResp updateMember(@Valid MemberUpdateModel entity) {
        return WxWorkUtils.postReq(new MemberUpdateResp(), WxWorkAddressBookApiType.Update_Member.getType(), entity);
    }

    /**
     * 删除成员
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90198
     */
    public static MemberDeleteResp deleteMember(@Valid MemberDeleteModel entity) {
        return WxWorkUtils.getReq(new MemberDeleteResp(), WxWorkAddressBookApiType.Delete_Member.getType(), entity);
    }

    /**
     * 批量删除成员
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90199
     */
    public static MemberBatchDeleteResp batchDeleteMember(@Valid MemberBatchDeleteModel entity) {
        return WxWorkUtils.postReq(new MemberBatchDeleteResp(), WxWorkAddressBookApiType.Batch_Delete_Member.getType(), entity);
    }

    /**
     * 获取部门成员（简单信息）
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90200
     */
    public static UserSimpleListResp userSimpleList(@Valid UserSimpleListModel entity) {
        return WxWorkUtils.getReq(new UserSimpleListResp(), WxWorkAddressBookApiType.User_Simple_List.getType(), entity);
    }

    /**
     * 获取部门成员详情
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90201
     */
    public static UserListResp userList(@Valid UserListModel entity) {
        return WxWorkUtils.getReq(new UserListResp(), WxWorkAddressBookApiType.User_List.getType(), entity);
    }

    /**
     * userid转openid
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90202
     */
    public static ToOpenIdResp convertToOpenId(@Valid ToOpenIdModel entity) {
        return WxWorkUtils.postReq(new ToOpenIdResp(), WxWorkAddressBookApiType.Convert_To_OpenId.getType(), entity);
    }

    /**
     * openid转userid
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90202
     */
    public static ToUserIdResp convertToUserId(@Valid ToUserIdModel entity) {
        return WxWorkUtils.postReq(new ToUserIdResp(), WxWorkAddressBookApiType.Convert_To_UserId.getType(), entity);
    }

    /**
     * 二次验证
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90203
     */
    public static AuthSuccResp authSucc(@Valid AuthSuccModel entity) {
        return WxWorkUtils.getReq(new AuthSuccResp(), WxWorkAddressBookApiType.Auth_Succ.getType(), entity);
    }

    /**
     * 邀请成员
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90975
     */
    public static InviteMemberResp inviteMember(InviteMemberModel entity) {
        return WxWorkUtils.postReq(new InviteMemberResp(), WxWorkAddressBookApiType.Invite.getType(), entity);
    }

    /**
     * 获取加入企业二维码
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/91714
     */
    public static GetJoinQrcodeResp getJoinQrcode(GetJoinQrcodeModel entity) {
        return WxWorkUtils.getReq(new GetJoinQrcodeResp(), WxWorkAddressBookApiType.Get_Join_Qrcode.getType(), entity);
    }

    /**
     * 获取企业活跃成员数
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/92714
     */
    public static GetActiveStatResp getActiveStat(GetActiveStatModel entity){
        return WxWorkUtils.postReq(new GetActiveStatResp(), WxWorkAddressBookApiType.Get_Active_Stat.getType(), entity);
    }


    /**
     * // 手机号获取userid
     * 参考：https://work.weixin.qq.com/api/doc/90001/90143/91693
     */
    public static GetUserIdResp getUserId(GetUserIdModel entity){
        return WxWorkUtils.postReq(new GetUserIdResp(), WxWorkAddressBookApiType.Get_Userid.getType(), entity);
    }

    /**
     * // 获取成员授权列表
     * 参考：https://work.weixin.qq.com/api/doc/90001/90143/94513
     */
    public static MemberAuthResp getMemberAuth(MemberAuthModel entity){
        return WxWorkUtils.postReq(new MemberAuthResp(), WxWorkAddressBookApiType.List_Member_Auth.getType(), entity);
    }

    /**
     * 查询成员用户是否已授权
     * 参考：https://work.weixin.qq.com/api/doc/90001/90143/94514
     */
    public static CheckMemberAuthResp selectMemberAuth(CheckMemberAuthModel entity){
        return WxWorkUtils.postReq(new CheckMemberAuthResp(), WxWorkAddressBookApiType.Check_Member_Auth.getType(), entity);
    }

    /**
     * 获取选人ticket对应的用户
     * 参考：https://work.weixin.qq.com/api/doc/90001/90143/94894
     */
    public static MemberAuthResp getTicketUser(MemberAuthModel entity){
        return WxWorkUtils.postReq(new MemberAuthResp(), WxWorkAddressBookApiType.List_Selected_Ticket_User.getType(), entity);
    }




    /************部门管理*************/
    /**
     * 创建部门
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90205
     */
    public static CreateDepartmentResp createDepartment(CreateDepartmentModel entity){
        return WxWorkUtils.postReq(new CreateDepartmentResp(), WxWorkAddressBookApiType.Create_Department.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/28 11:22
     *  @Description:更新部门
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90206
     */
    public static BaseRespModel updateDepartment(UpdateDepartmentModel entity){
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkAddressBookApiType.Update_Department.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/28 11:22
     *  @Description:删除部门
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90206
     */
    public static BaseRespModel deleteDepartment(DeleteDepartmentModel entity){
        return WxWorkUtils.getReq(new BaseRespModel(), WxWorkAddressBookApiType.Delete_Department.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/28 11:22
     *  @Description:查询部门列表（获取本部门及子部门列表）
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90208
     */
    public static DepartmentListResp getDepartmentList(GetDepartmentListModel entity){
        return WxWorkUtils.getReq(new DepartmentListResp(), WxWorkAddressBookApiType.List_Department.getType(), entity);
    }

    /*************标签管理***************/
    /**
     *  @author: maxm
     *  @Date: 2021/1/28 13:06
     *  @Description:创建标签
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90210
     */
    public static CreateTagResp createTag(CreateTagModel entity){
        return WxWorkUtils.postReq(new CreateTagResp(), WxWorkAddressBookApiType.Create_Tag.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/28 13:06
     *  @Description:更新标签
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90211
     */
    public static BaseRespModel updateTag(UpdateTagModel entity){
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkAddressBookApiType.Update_Tag.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/28 13:06
     *  @Description:删除标签
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90212
     */
    public static BaseRespModel deleteTag(DeleteTagModel entity){
        return WxWorkUtils.getReq(new BaseRespModel(), WxWorkAddressBookApiType.Delete_Tag.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/28 13:06
     *  @Description:获取标签成员
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90213
     */
    public static GetTagUserResp getTagUser(GetTagUserModel entity){
        return WxWorkUtils.getReq(new GetTagUserResp(), WxWorkAddressBookApiType.Get_Tag_User.getType(), entity);
    }
    /**
     *  @author: maxm
     *  @Date: 2021/1/28 13:06
     *  @Description:增加标签成员
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90214
     */
    public static BaseRespModel addTagUsers(AddTagUserResp entity){
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkAddressBookApiType.Add_Tag_User.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/29 13:06
     *  @Description:删除标签成员
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90215
     */
    public static BaseRespModel deleteTagUsers(DeleteTagUserResp entity){
        return WxWorkUtils.postReq(new BaseRespModel(), WxWorkAddressBookApiType.Delete_Tag_User.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/29 13:06
     *  @Description:删除标签成员
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90215
     */
    public static GetTagListResp getTagList(BaseReqModel entity){
        return WxWorkUtils.getReq(new GetTagListResp(), WxWorkAddressBookApiType.Get_Tag_List.getType(), entity);
    }

    /****异步批量接口***********/

    /**
     *  @author: maxm
     *  @Date: 2021/1/29 17:27
     *  @Description:增量更新成员
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90980
     */
    public static BatchUpdateUserResp batchUpdateUser(BatchUpdateUserReq entity){
        return WxWorkUtils.postReq(new BatchUpdateUserResp(), WxWorkAddressBookApiType.Batch_Update_User.getType(), entity);
    }
    /**
     *  @author: maxm
     *  @Date: 2021/1/29 17:27
     *  @Description:全量覆盖成员
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90981
     */
    public static BatchUpdateUserResp batchReplaceUser(BatchUpdateUserReq entity){
        return WxWorkUtils.postReq(new BatchUpdateUserResp(), WxWorkAddressBookApiType.Batch_Replace_User.getType(), entity);
    }
    /**
     *  @author: maxm
     *  @Date: 2021/1/29 17:27
     *  @Description:全量覆盖部门
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90982
     */
    public static BatchUpdateUserResp batchReplaceParty(BatchUpdateUserReq entity){
        return WxWorkUtils.postReq(new BatchUpdateUserResp(), WxWorkAddressBookApiType.Batch_Replace_Party.getType(), entity);
    }

    /**
     *  @author: maxm
     *  @Date: 2021/1/29 17:27
     *  @Description:获取异步任务结果
     *  参考：https://work.weixin.qq.com/api/doc/90000/90135/90983
     */
    public static BatchGetResultReqResp batchGetResult(BatchGetResultReq entity){
        return WxWorkUtils.getReq(new BatchGetResultReqResp(), WxWorkAddressBookApiType.Batch_Get_Result.getType(), entity);
    }

    /**********消息推送 ************/
    /**
     * 发送应用消息
     * 参考：https://work.weixin.qq.com/api/doc/90000/90135/90236
     */
    public static MessageSendResp MessageSend(MessageSendReq entity){
        return WxWorkUtils.postReq(new MessageSendResp(), WxWorkAddressBookApiType.Message_Send.getType(), entity);
    }

}
